@@ -5,139 +5,154 @@ use strict;
 use warnings;
 use feature qw(state);
 
-use Getopt::Long qw(:config no_ignore_case no_ignore_case_always);
+use App::ElasticSearch::Utilities qw(es_request es_pattern es_nodes es_indices es_index_strip_date);
+use CLI::Helpers qw(:output);
+use Getopt::Long::Descriptive;
 use Pod::Usage;
-use CLI::Helpers qw(:all);
-use App::ElasticSearch::Utilities qw(es_request es_pattern es_nodes es_indices);
 
 #------------------------------------------------------------------------#
 # Argument Collection
-my %opt;
-GetOptions(\%opt,
-    'sort:s',
-    'format:s',
-    'view:s',
-    'close',
-    'limit:i',
-    'asc',
-    'desc',
-    # Basic options
-    'help|h',
-    'manual|m',
+my ($opt,$usage) = describe_options('%c %o',
+    ['all',     "Scan all indices instead of processing the --base/--days parameters"],
+    ['sort:s',  "sort by name or size, default: name",
+            { default => 'name', callbacks => { 'must be name or size' => sub { $_[0] =~ /^name|size$/ } } }
+    ],
+    ['view:s',  "Show by index, base or node, default: node",
+          { default => 'node', callbacks => { 'must be base, index, or node' => sub { $_[0] =~ /^base|index|node$/ } } }
+    ],
+    ['asc',     "Sort ascending  (default by name)"],
+    ['desc',    "Sort descending (default by size)"],
+    ['limit:i', "Limit to showing only this many, ie top N", { default => 0 }],
+    ['raw',     "Display numeric data without rollups"],
+    [],
+    ['help|h',  "Display this help", { shortcircuit => 1 }],
+    ['manual|m',"Display the full manual", { shortcircuit => 1 }],
 );
 
 #------------------------------------------------------------------------#
 # Documentations!
-pod2usage(1) if $opt{help};
-pod2usage(-exitstatus => 0, -verbose => 2) if $opt{manual};
-
-# Configuration
-my %CFG = (
-    sort      => 'name',
-    format    => 'pretty',
-    view      => 'node',
-    limit     => 0,
-);
-my %VALID = (
-    format => {map { $_ => 1 } qw(pretty raw)},
-    view   => {map { $_ => 1 } qw(node index)},
-);
-# Extract from our options if we've overridden defaults
-foreach my $setting (keys %CFG) {
-    if ( exists $opt{$setting} and defined $opt{$setting} ) {
-        if( exists $VALID{$setting} ) {
-            if(exists $VALID{$setting}->{$opt{$setting}}) {
-                $CFG{$setting} = $opt{$setting};
-            }
-            else {
-                output({color=>'red',stderr=>1},
-                    "Invalid option for $setting: '$opt{$setting}', valid are: " . join(',', sort keys %{ $VALID{$setting} })
-                );
-            }
-        }
-        else {
-            $CFG{$setting} = $opt{$setting};
-        }
-    }
+if( $opt->help ) {
+    print $usage->text;
+    exit;
 }
+pod2usage(-exitstatus => 0, -verbose => 2) if $opt->manual;
+
 # Get the pattern we're using
 my $PATTERN = es_pattern();
 
 # Indices and Nodes
-my @INDICES = es_indices();
-my %NODES = es_nodes();
+my @INDICES = es_indices($opt->all ? ( _all => 1 ) : ());
+my %NODES   = es_nodes();
 
 # Loop through the indices and take appropriate actions;
 my %indices = ();
 my %nodes = ();
+my %bases = ();
+my %overview = (
+    shards  => 0,
+    indices => 0,
+    docs    => 0,
+    size    => 0,
+);
 foreach my $index (@INDICES) {
     verbose({color=>'green'}, "$index - Gathering statistics");
 
+    $overview{indices}++;
+
     my $result = es_request('_status', { index => $index });
     if( !defined $result ) {
         output({color=>'magenta',indent=>1}, "+ Unable to fetch index status!");
         next;
     }
     verbose({indent=>1}, "+ Succesful");
-    my $status = $result->{indices}{$index};
+    my $status = $result->{indices}{$index}{primaries};
     debug("index_status( $index ");
     debug_var($status);
 
+    # Grab Index Data
     $indices{$index} = {
-        size        => $status->{index}{size_in_bytes},
-        size_pretty => $status->{index}{size},
-        docs        => $status->{docs}{num_docs},
+        size        => $status->{store}{size_in_bytes},
+        docs        => $status->{docs}{count},
     };
+
+    # Update the Overview
+    $overview{size} += $status->{store}{size_in_bytes};
+    $overview{docs} += $status->{docs}{count};
+
+    my $base = es_index_strip_date($index);
+    $bases{$base} ||=  { size => 0, docs => 0 };
+    $bases{$base}->{size} += $status->{store}{size_in_bytes};
+    $bases{$base}->{docs} += $status->{docs}{count};
+
+    my $shards = es_request("_cat/shards/$index",
+        { uri_param => { qw(bytes b format json) }}
+    );
+
     my %shards = ();
-    foreach my $shard (keys %{ $status->{shards} }) {
-        foreach my $instance (@{ $status->{shards}{$shard} }) {
-            my $node = $NODES{$instance->{routing}{node}};
+    foreach my $s (@{ $shards }) {
+        my ($node) = ($s->{node} =~ /^(\S+)/);
+        $shards{$s->{shard}} ||= {};
+        $nodes{$node}   ||= {};
 
-            $shards{$shard} ||= {};
-            $nodes{$node}   ||= {};
+        $overview{shards}++;
 
-            if( exists $shards{$shard}->{$node} ) {
-                $shards{$shard}->{$node}{size} += $instance->{index}{size_in_bytes};
-                $shards{$shard}->{$node}{docs} += $instance->{docs}{num_docs};
-            }
-            else {
-                $shards{$shard}->{$node} = {
-                    size => $instance->{index}{size_in_bytes},
-                    docs => $instance->{docs}{num_docs},
-                };
-            }
-            no warnings;
-            $nodes{$node}->{$_} ||= 0 for qw(size shards docs);
-            $nodes{$node}->{size} += $instance->{index}{size_in_bytes};
-            $nodes{$node}->{shards}++;
-            $nodes{$node}->{docs} += $instance->{docs}{num_docs};
+        if( exists $shards{$s->{shard}}->{$node} ) {
+            $shards{$s->{shard}}->{$node}{size} += $s->{store};
+            $shards{$s->{shard}}->{$node}{docs} += $s->{docs};
         }
+        else {
+            $shards{$s->{shard}}->{$node} = {
+                size => $s->{store},
+                docs => $s->{docs},
+            };
+        }
+        no warnings;
+        $nodes{$node}->{$_} ||= 0 for qw(size shards docs);
+        $nodes{$node}->{size} += $s->{store};
+        $nodes{$node}->{shards}++;
+        $nodes{$node}->{docs} += $s->{docs};
     }
     $indices{$index}->{shards} = \%shards;
 }
 
-output({color=>'white'}, "Storage data for $CFG{view} from indices matching '$PATTERN->{string}'");
-if( $CFG{view} eq 'index' ) {
+output({color=>'white'}, sprintf "Storage data for %s from indices matching '%s'", $opt->view, $PATTERN->{string});
+if( $opt->view eq 'index' ) {
     my $displayed = 0;
     foreach my $index (sort indices_by keys %indices) {
         output({color=>"magenta",indent=>1}, $index);
         output({color=>"cyan",kv=>1,indent=>2}, 'size', pretty_size( $indices{$index}->{size}));
         output({color=>"cyan",kv=>1,indent=>2}, 'docs', $indices{$index}->{docs});
         $displayed++;
-        last if $CFG{limit} > 0 && $displayed >= $CFG{limit};
+        last if $opt->limit > 0 && $displayed >= $opt->limit;
     }
 }
-elsif( $CFG{view} eq 'node' ) {
+if( $opt->view eq 'base' ) {
+    my $displayed = 0;
+    %indices = %bases;
+    foreach my $index (sort indices_by keys %bases) {
+        output({color=>"magenta",indent=>1}, $index);
+        output({color=>"cyan",kv=>1,indent=>2}, 'size', pretty_size( $bases{$index}->{size}));
+        output({color=>"cyan",kv=>1,indent=>2}, 'docs', $bases{$index}->{docs});
+        $displayed++;
+        last if $opt->limit > 0 && $displayed >= $opt->limit;
+    }
+}
+elsif( $opt->view eq 'node' ) {
     my $displayed = 0;
     foreach my $node (sort nodes_by keys %nodes) {
         output({color=>"magenta",indent=>1}, $node);
-        output({color=>"cyan",kv=>1,indent=>2}, 'size', pretty_size( $nodes{$node}->{size}));
-        output({color=>"cyan",kv=>1,indent=>2}, 'shards',  $nodes{$node}->{shards});
-        output({color=>"cyan",kv=>1,indent=>2}, 'docs',  $nodes{$node}->{docs});
+        output({color=>"cyan",kv=>1,indent=>2}, 'size',   pretty_size( $nodes{$node}->{size}));
+        output({color=>"cyan",kv=>1,indent=>2}, 'shards', $nodes{$node}->{shards});
+        output({color=>"cyan",kv=>1,indent=>2}, 'docs',   $nodes{$node}->{docs});
         $displayed++;
-        last if $CFG{limit} > 0 && $displayed >= $CFG{limit};
+        last if $opt->limit > 0 && $displayed >= $opt->limit;
     }
 }
+output({color=>'white',clear=>1},"Total for scanned data");
+    output({color=>"cyan",kv=>1,indent=>1}, 'size',   pretty_size( $overview{size}));
+    output({color=>"cyan",kv=>1,indent=>1}, 'shards', $overview{shards});
+    output({color=>"cyan",kv=>1,indent=>1}, 'docs',   $overview{docs});
+
 
 exit (0);
 
@@ -146,7 +161,7 @@ sub pretty_size {
     state $warned = 0;
 
     my $value = $size;
-    if( $CFG{format} eq 'pretty' ) {
+    if( !$opt->raw ) {
         my @indicators = qw(kb mb gb tb);
         my $indicator = '';
 
@@ -161,19 +176,21 @@ sub pretty_size {
 }
 
 sub indices_by {
-    if( exists $opt{sort} && $opt{sort} eq 'size' ) {
-        return exists $opt{asc} ?
+    if( $opt->sort eq 'size' ) {
+        return $opt->asc ?
             $indices{$a}->{size} <=> $indices{$b}->{size} :
             $indices{$b}->{size} <=> $indices{$a}->{size} ;
     }
-    return exists $opt{asc} ? $a cmp $b : $b cmp $a;
+    return $opt->desc ? $b cmp $a : $a cmp $b;
 }
 
 sub nodes_by {
-    if( exists $opt{sort} && $opt{sort} eq 'size' ) {
-        return $nodes{$b}->{size} <=> $nodes{$a}->{size};
+    if( $opt->sort eq 'size' ) {
+        return $opt->asc ?
+            $nodes{$a}->{size} <=> $nodes{$b}->{size} :
+            $nodes{$b}->{size} <=> $nodes{$a}->{size} ;
     }
-    return exists $opt{asc} ? $a cmp $b : $b cmp $a;
+    return $opt->desc ? $b cmp $a : $a cmp $b;
 }
 
 __END__
@@ -188,7 +205,7 @@ es-storage-data.pl - Index pattern-aware elasticsearch storage statistics
 
 =head1 VERSION
 
-version 5.5
+version 5.6
 
 =head1 SYNOPSIS
 
@@ -280,11 +297,11 @@ Show only the first N items, or everything is N == 0
 
 =item B<asc>
 
-Sort ascending
+Sort ascending, the default for name
 
 =item B<desc>
 
-Sort descending, the default
+Sort descending, the default for size
 
 =back
 
